pub struct CreateIncreasePositionRequest {Show 17 fields
pub owner: Pubkey,
pub funding_account: Pubkey,
pub perpetuals: Pubkey,
pub pool: Pubkey,
pub position: Pubkey,
pub position_request: Pubkey,
pub position_request_ata: Pubkey,
pub custody: Pubkey,
pub custody_oracle_account: Pubkey,
pub collateral_custody: Pubkey,
pub input_mint: Pubkey,
pub referral: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub system_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for CreateIncreasePositionRequest.
Fields
owner: Pubkeyfunding_account: Pubkeyperpetuals: Pubkeypool: Pubkeyposition: Pubkeyposition_request: Pubkeyposition_request_ata: Pubkeycustody: Pubkeycustody_oracle_account: Pubkeycollateral_custody: Pubkeyinput_mint: Pubkeyreferral: Pubkeytoken_program: Pubkeyassociated_token_program: Pubkeysystem_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateIncreasePositionRequestwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateIncreasePositionRequestwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateIncreasePositionRequest
impl ToAccountMetas for CreateIncreasePositionRequest
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateIncreasePositionRequest
impl RefUnwindSafe for CreateIncreasePositionRequest
impl Send for CreateIncreasePositionRequest
impl Sync for CreateIncreasePositionRequest
impl Unpin for CreateIncreasePositionRequest
impl UnwindSafe for CreateIncreasePositionRequest