pub struct Init {
pub upgrade_authority: Pubkey,
pub admin: Pubkey,
pub transfer_authority: Pubkey,
pub perpetuals: Pubkey,
pub perpetuals_program: Pubkey,
pub perpetuals_program_data: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for Init.
Fields
admin: Pubkeyperpetuals: Pubkeyperpetuals_program: Pubkeyperpetuals_program_data: Pubkeysystem_program: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Initwhere
Pubkey: BorshSerialize,
impl BorshSerialize for Initwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Init
impl ToAccountMetas for Init
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Init
impl RefUnwindSafe for Init
impl Send for Init
impl Sync for Init
impl Unpin for Init
impl UnwindSafe for Init