pub struct SetPoolConfig {
pub admin: Pubkey,
pub perpetuals: Pubkey,
pub pool: Pubkey,
}Expand description
Generated client accounts for SetPoolConfig.
Fields
admin: Pubkeyperpetuals: Pubkeypool: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetPoolConfigwhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetPoolConfigwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetPoolConfig
impl ToAccountMetas for SetPoolConfig
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetPoolConfig
impl RefUnwindSafe for SetPoolConfig
impl Send for SetPoolConfig
impl Sync for SetPoolConfig
impl Unpin for SetPoolConfig
impl UnwindSafe for SetPoolConfig