pub struct SetTestOraclePrice {
pub admin: Pubkey,
pub perpetuals: Pubkey,
pub pool: Pubkey,
pub custody: Pubkey,
pub oracle_account: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for SetTestOraclePrice.
Fields
admin: Pubkeyperpetuals: Pubkeypool: Pubkeycustody: Pubkeyoracle_account: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetTestOraclePricewhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetTestOraclePricewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetTestOraclePrice
impl ToAccountMetas for SetTestOraclePrice
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetTestOraclePrice
impl RefUnwindSafe for SetTestOraclePrice
impl Send for SetTestOraclePrice
impl Sync for SetTestOraclePrice
impl Unpin for SetTestOraclePrice
impl UnwindSafe for SetTestOraclePrice