pub struct Position {Show 14 fields
pub owner: Pubkey,
pub pool: Pubkey,
pub custody: Pubkey,
pub collateral_custody: Pubkey,
pub open_time: i64,
pub update_time: i64,
pub side: Side,
pub price: u64,
pub size_usd: u64,
pub collateral_usd: u64,
pub realised_pnl_usd: i64,
pub cumulative_interest_snapshot: u128,
pub locked_amount: u64,
pub bump: u8,
}Expand description
Account: Position
Fields
owner: Pubkeypool: Pubkeycustody: Pubkeycollateral_custody: Pubkeyopen_time: i64update_time: i64side: Sideprice: u64size_usd: u64collateral_usd: u64realised_pnl_usd: i64cumulative_interest_snapshot: u128locked_amount: u64bump: u8Trait Implementations
Sourceimpl AccountDeserialize for Position
impl AccountDeserialize for Position
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Position
impl AccountSerialize for Position
Sourceimpl BorshDeserialize for Position
impl BorshDeserialize for Position
Sourceimpl BorshSerialize for Positionwhere
Pubkey: BorshSerialize,
i64: BorshSerialize,
Side: BorshSerialize,
u64: BorshSerialize,
u128: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for Positionwhere
Pubkey: BorshSerialize,
i64: BorshSerialize,
Side: BorshSerialize,
u64: BorshSerialize,
u128: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Discriminator for Position
impl Discriminator for Position
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for Position