pub struct TestOracle {
pub price: u64,
pub expo: i32,
pub conf: u64,
pub publish_time: i64,
}Expand description
Account: TestOracle
Fields
price: u64expo: i32conf: u64publish_time: i64Trait Implementations
Sourceimpl AccountDeserialize for TestOracle
impl AccountDeserialize for TestOracle
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for TestOracle
impl AccountSerialize for TestOracle
Sourceimpl BorshDeserialize for TestOracle
impl BorshDeserialize for TestOracle
Sourceimpl BorshSerialize for TestOracle
impl BorshSerialize for TestOracle
Sourceimpl Clone for TestOracle
impl Clone for TestOracle
Sourcefn clone(&self) -> TestOracle
fn clone(&self) -> TestOracle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TestOracle
impl Default for TestOracle
Sourcefn default() -> TestOracle
fn default() -> TestOracle
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for TestOracle
impl Discriminator for TestOracle
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for TestOracle